/* chatline.c -- PLACEHOLDER */

#include "chatline.h"


void
real_append_output_window(const char *astring)
{
	/* PORTME */
}

void
log_output_window(void)
{
	/* PORTME */
}

void
clear_output_window(void)
{
	/* PORTME */
}
